<?php

if ( ! defined( 'ABSPATH' ) ) exit;

class WooCommerce_Shipmate_Settings {

	/**
	 * The single instance of WooCommerce_Shipmate_Settings.
	 * @var 	object
	 * @access  private
	 * @since 	1.0.0
	 */
	private static $_instance = null;

	/**
	 * The main plugin object.
	 * @var 	object
	 * @access  public
	 * @since 	1.0.0
	 */
	public $parent = null;

	/**
	 * Prefix for plugin settings.
	 * @var     string
	 * @access  public
	 * @since   1.0.0
	 */
	public $base = '';

	/**
	 * Available settings for plugin.
	 * @var     array
	 * @access  public
	 * @since   1.0.0
	 */
	public $settings = array();

	public function __construct ( $parent ) {
		$this->parent = $parent;

		$this->base = 'wpt_';

		$this->shipmate_integration = new WooCommerce_Shipmate_Integration();



		// Add the appropriate settings page
		add_filter( 'woocommerce_get_settings_pages', array( $this, 'add_settings_pages' ) );


		if(!empty(get_option('shipmate_sender_token', null))) {
			add_action( 'add_meta_boxes', array ( $this, 'add_order_meta_box' ) );
			add_action( 'woocommerce_product_options_shipping', array($this, 'woocommerce_product_custom_fields')); 
			add_action( 'woocommerce_process_product_meta', array($this, 'woocommerce_product_custom_fields_save'));
		}
	}


	public function woocommerce_product_custom_fields () {
		    woocommerce_wp_text_input(
			    array(
			        'id' => '_shipmate_hs_code',
			        'placeholder' => '6109100010',
			        'desc_tip' => true,
			        'description' => 'Shipmate requires all internaional shipments going outside of the eurozone to have a HS Tariff Code. E.g. 6109100010',
			        'label' => __('Shipmate HS Code', 'woocommerce'),
			        'type' => 'text',
			    )
			);

			woocommerce_wp_text_input(
			    array(
			        'id' => '_shipmate_short_description',
			        'placeholder' => 'Red T-shirt',
			        'desc_tip' => true,
			        'description' => 'Shipmate requires all internaional shipments going outside of the eurozone to have a short product description. E.g. Red T-shirt',
			        'label' => __('Shipmate Product Short Description', 'woocommerce'),
			        'type' => 'text',
			    )
			);

			woocommerce_wp_text_input(
			    array(
			        'id' => '_shipmate_full_description',
			        'placeholder' => '100% Cotton Red T-shirt',
			        'desc_tip' => true,
			         'description' => 'Shipmate requires all internaional shipments going outside of the eurozone to have a full product description. E.g. 100% Cotton Red T-shirt',
			        'label' => __('Shipmate Product Full Description', 'woocommerce'),
			        'type' => 'text',
			    )
			);
			$countries_obj   = new WC_Countries();
    		$countries   = $countries_obj->__get('countries');
			woocommerce_wp_select(
			    array(
			        'id' => '_shipmate_country_of_origin',
			        'placeholder' => 'United Kingdom',
			        'desc_tip' => true,
			         'description' => 'Shipmate requires all internaional shipments going outside of the eurozone to have a country of origin. E.g. United Kingdom',
			        'label' => __('Shipmate Country Of Origin', 'woocommerce'),
			        'options'    => $countries,
			    )
			);
    }

    public function woocommerce_product_custom_fields_save($post_id) {
    	$woocommerce_custom_shipping_hs_code = $_POST['_shipmate_hs_code'];
    	if (!empty($woocommerce_custom_shipping_hs_code)) {
    		 update_post_meta($post_id, '_shipmate_hs_code', esc_attr($woocommerce_custom_shipping_hs_code));
    	}

    	$woocommerce_custom_shipping_short_description = $_POST['_shipmate_short_description'];
    	if (!empty($woocommerce_custom_shipping_short_description)) {
    		 update_post_meta($post_id, '_shipmate_short_description', esc_attr($woocommerce_custom_shipping_short_description));
    	}

    	$woocommerce_custom_shipping_full_description = $_POST['_shipmate_full_description'];
    	if (!empty($woocommerce_custom_shipping_full_description)) {
    		 update_post_meta($post_id, '_shipmate_full_description', esc_attr($woocommerce_custom_shipping_full_description));
    	}

    	$woocommerce_custom_shipping_country_of_origin = $_POST['_shipmate_country_of_origin'];
    	if (!empty($woocommerce_custom_shipping_country_of_origin)) {
    		 update_post_meta($post_id, '_shipmate_country_of_origin', esc_attr($woocommerce_custom_shipping_country_of_origin));
    	}
    }

	public function add_order_meta_box() {
		// add Order Meta Box
		add_meta_box( 'woocommerce-order-shipmate', __( 'Shipmate Data', 'woocommerce' ) . wc_help_tip( __( 'Print your shipping labels with Shipmate.', 'woocommerce' ) ), 'WooCommerce_Shipmate_Order_Metabox::output', 'shop_order', 'side', 'default' );
	}

	// adds either the authenticated or unauthenticated settings page
	public function add_settings_pages($sections) {
		// if($this->shipmate_integration->is_integrated()) {
		// 	$sections[] = include('settings/class-woocommerce-shipmate-settings-authenticated.php');
		// } else {
		// 	$sections[] = include('settings/class-woocommerce-shipmate-settings-unauthenticated.php');
		// }

		$sections[] = include('settings/class-woocommerce-shipmate-settings-tab.php');

		return $sections;
	}


	function integration_settings() {
		if($this->shipmate_integration->is_integrated()) {
			$settings = array(
		        'section_title' => array(
		            'name'     => __( 'Your Shipmate Integration', 'woocommerce-settings-tab-shipmate' ),
		            'type'     => 'title',
		            'desc'     => '',
		            'id'       => 'wc_settings_tab_shipmate_section_title'
		        ),
		        'sender_name' => array(
		            'name' => __( 'Sender Name', 'woocommerce-settings-tab-shipmate' ),
		            'type' => 'text',
		            'id'   => 'wc_settings_tab_shipmate_sender_name',
					'default'  => $this->shipmate_integration->sender_name(),
		        ),
		        'api_key' => array(
		            'name' => __( 'Description', 'woocommerce-settings-tab-shipmate' ),
		            'type' => 'text',
		            'id'   => 'wc_settings_tab_shipmate_api_key',
					'default'  => $this->shipmate_integration->token(),
		        ),
		        'section_end' => array(
		             'type' => 'sectionend',
		             'id' => 'wc_settings_tab_shipmate_section_end'
		        )
		    );
	    	return apply_filters( 'wc_settings_tab_shipmate_settings', $settings );	
		} else {
			
	    }
	}

	/**
	 * Main WooCommerce_Shipmate_Settings Instance
	 *
	 * Ensures only one instance of WooCommerce_Shipmate_Settings is loaded or can be loaded.
	 *
	 * @since 1.0.0
	 * @static
	 * @see WooCommerce_Shipmate()
	 * @return Main WooCommerce_Shipmate_Settings instance
	 */
	public static function instance ( $parent ) {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self( $parent );
		}
		return self::$_instance;
	} // End instance()

	/**
	 * Cloning is forbidden.
	 *
	 * @since 1.0.0
	 */
	public function __clone () {
		_doing_it_wrong( __FUNCTION__, __( 'Cheatin&#8217; huh?' ), $this->parent->_version );
	} // End __clone()

	/**
	 * Unserializing instances of this class is forbidden.
	 *
	 * @since 1.0.0
	 */
	public function __wakeup () {
		_doing_it_wrong( __FUNCTION__, __( 'Cheatin&#8217; huh?' ), $this->parent->_version );
	} // End __wakeup()

}
