<?php

if ( ! defined( 'ABSPATH' ) ) exit;

class WooCommerce_Shipmate_Integration {

	protected $sender_token = null;
	protected $sender_name = null;

    protected $is_live = false;

	const SENDER_KEY_ID = "shipmate_sender_token";
    const SENDER_NAME = "shipmate_sender_name";
    const IS_LIVE_ID = "shipmate_is_live";

	/**
	 * Constructor function.
	 * @access  public
	 * @since   1.0.0
	 * @return  void
	 */
	public function __construct () {
		$this->sender_token = get_option(self::SENDER_KEY_ID, null);
        $this->sender_name = get_option(self::SENDER_NAME, null);
        $this->is_live = get_option(self::IS_LIVE_ID, false);
	} // End __construct ()

    public function save($token, $name, $is_live) {
        update_option(self::SENDER_KEY_ID, $token);
        update_option(self::SENDER_NAME, $name);
        update_option(self::IS_LIVE_ID, $is_live);
    }
    
    public function delete() {
        update_option(self::SENDER_KEY_ID, "");
        update_option(self::SENDER_NAME, "");
        update_option(self::IS_LIVE_ID, "");
    }

    public function token() {
        return !empty($this->sender_token) ? $this->sender_token : '';
    }

    public function convert_carrier_to_provider($carrier) {

        // $providers['United Kingdom']['DPD Local'] = 'http://www.dpdlocal.co.uk/apps/tracking/?reference=%1$s';
        // $providers['United Kingdom']['Whistl'] = 'https://trackmyitem.whistl.co.uk/tracking/%1$s';
        // $providers['United Kingdom']['UPS'] = 'https://wwwapps.ups.com/WebTracking/processRequest?&tracknum=%1$s';
        // $providers['United Kingdom']['Yodel'] = 'http://www.yodel.co.uk/tracking/%1$s';
        if($carrier == "DPDLOCAL") {
            return "DPD Local";
        } else if ($carrier == "WHISTL") {
            return "Whistl";
        } else if ($carrier == "UPS") {
            return "UPS";
        } else if ($carrier == "YODEL") {
            return "Yodel";
        }

        return $carrier;
    }

    public static function version_check( $version ) {
        if ( class_exists( 'WooCommerce' ) ) {
            global $woocommerce;
            if ( version_compare( $woocommerce->version, $version, ">=" ) ) {
                return true;
            }
        }
        return false;
    }

    /**
     * Returns a boolean true / false if the integration is aimed at the live environment
     *
     * @return boolean
     */
    public function is_live() {
        return $this->is_live;
    }

    /**
     * Returns a boolean true / false if there is a sender api key and auth token
     *
     * @return boolean
     */
	public function is_integrated() {
		return !empty($this->sender_token());
	}

    /**
     * Gets the value of sender_token.
     *
     * @return mixed
     */
    public function sender_token()
    {
        return $this->sender_token;
    }

    /**
     * Sets the value of sender_token.
     *
     * @param mixed $sender_token the sender api key
     *
     * @return self
     */
    public function set_sender_token($sender_token)
    {
        $this->sender_token = $sender_token;
    }

    /**
     * Gets the value of sender_name.
     *
     * @return mixed
     */
    public function sender_name()
    {
        return $this->sender_name;
    }
}
